@@ -15,7 +15,7 @@ use URI::Escape qw{uri_escape_utf8};
 # of ExtUtils::MakeMaker->WriteMakefile() will accurately detect $VERSION.
 #
 my
-$VERSION = '1.000005';
+$VERSION = '1.000006';
 
 #
 # See https://tech.yandex.ru/translate/doc/dg/concepts/api-overview-docpage/
@@ -42,14 +42,14 @@ my %valid_default_ui = map { $_ => 1 } qw{ en ru tr };
 # otherwise, set it to English.
 #
 (my $default_ui = setlocale(LC_CTYPE) || 'en') =~ s/_.*$//;
-$default_ui = 'en' if ($default_ui ne 'ru' || $default_ui ne 'tr');
+$default_ui = 'en' if (!exists $valid_default_ui{$default_ui});
 
 sub new
 {
     my $class = shift;
     my $self = {
         _key_        => shift,
-        _text_       => uri_escape_utf8(shift),
+        _text_       => sub { my $t = shift; return (defined $t) ? uri_escape_utf8($t) : $t },
         _from_lang_  => shift,
         _to_lang_    => shift,
         _ui_         => shift || $default_ui,
@@ -199,6 +199,7 @@ sub translate
 # See §2.7 of Terms of Use of API Yandex.Translate Service
 # at https://yandex.com/legal/translate_api/
 #
+
 sub get_yandex_technology_reference
 {
     my ( $self, $attribute ) = @_;
@@ -224,7 +225,7 @@ sub get_yandex_technology_reference
         my %yandex_text = (
             ru => 'Переведено сервисом Яндекс.Переводчик',
             en => 'Powered by Yandex.Translate',
-	    tr => 'Tarafından desteklenmektedir Yandex.Translate',
+	    tr => 'Tarafından desteklenmektedir Yandex.Çeviri',
         );
         my $yandex_url = (exists $yandex_url{$self->{_ui_}}) ? $yandex_url{$self->{_ui_}} : $yandex_url{$default_ui};
         my $yandex_text = (exists $yandex_text{$self->{_ui_}}) ? $yandex_text{$self->{_ui_}} : $yandex_text{$default_ui};
@@ -244,7 +245,7 @@ Yandex::Translate - a simple API for Yandex.Translate
 
 =head1 VERSION
 
-version 1.000005
+version 1.000006
 
 =head1 SYNOPSIS
 
@@ -364,7 +365,7 @@ For example, French would be given as C<fr>.
     $tr->set_default_ui('ru');
 
 This method is used to set the default user interface language (string).
-Either C<ru> (Russian) or C<en> (English) can be given.
+Either C<ru> (Russian) or C<en> (English) or C<tr> (Turkish)  can be given.
 
 =head2 set_hint
 
@@ -468,3 +469,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
